@@ -3,6 +3,7 @@ Check the glottolog data for consistency.
 """
 import collections
 
+from clldutils.jsonlib import load
 from pyglottolog.languoids import Reference
 from pyglottolog.util import message
 import pyglottolog.iso
@@ -19,6 +20,11 @@ def register(parser):
         action='store_true',
         default=False,
     )
+    parser.add_argument(
+        '--old-languoids',
+        action='store_true',
+        default=False,
+    )
 
 
 def run(args):
@@ -56,14 +62,34 @@ def run(args):
             if ref_id and ref_id not in refkeys:
                 error(obj, 'missing reference: {0}'.format(ref_id))
 
+    old_languoids = load(args.repos.build_path('languoids.json')) if args.old_languoids else None
+    old_languages_count = len(old_languoids['language']) if old_languoids else 0
     for lang in args.repos.languoids():
         # duplicate glottocodes:
         if lang.id in languoids:
             error(
                 lang.id,
                 'duplicate glottocode\n{0}\n{1}'.format(languoids[lang.id].dir, lang.dir))
+        if old_languoids:
+            if lang.id in old_languoids[lang.level.name]:
+                old_languoids[lang.level.name].remove(lang.id)
         languoids[lang.id] = lang
 
+    if old_languoids:
+        for gc in old_languoids['language']:
+            if gc not in languoids:
+                error(gc, 'deleted language level languoid!')
+            else:
+                args.log.warning(
+                    '{} switched from language to {}'.format(gc, languoids[gc].level.name))
+        if not old_languoids['language']:
+            args.log.info(
+                'All {} language level languoids still present'.format(old_languages_count))
+        for level in ['family', 'dialect']:
+            if old_languoids[level]:
+                args.log.info(
+                    '{} {} level languoids deleted'.format(len(old_languoids[level]), level))
+
     for lang in languoids.values():
         ancestors = lang.ancestors_from_nodemap(languoids)
         children = lang.children_from_nodemap(languoids)
