@@ -51,9 +51,22 @@ def test_pattern(input_, valid, _match=Glottocode.pattern.match):
     assert (_match(input_) is not None) == valid
 
 
-def test_Country():
-    assert Country.from_text('Germany').id == 'DE'
+@pytest.mark.parametrize('text, expected_id, expected_str', [
+    ('Germany', 'DE', 'DE'),
+    ('Russian Federation (RU)', 'RU', 'RU'),
+    ('RU', 'RU', 'RU'),
+])
+def test_Country_from_text(text, expected_id, expected_str):
+    country = Country.from_text(text)
+    assert country.id == expected_id
+    assert str(country) == expected_str
+
+
+def test_Country_from_name():
     assert Country.from_name('abcdefg') is None
+
+
+def test_Country_from_id():
     assert Country.from_id('abcdefg') is None
 
 
@@ -126,7 +139,7 @@ def test_endangerment(api):
     assert 'source' in lang.endangerment.__json__()
 
 
-def test_timespan(api, tmpdir):
+def test_timespan(api, tmpdir, recwarn):
     assert api.languoid('abcd1235').timespan == None
 
     with pytest.raises(ValueError):
@@ -138,9 +151,11 @@ def test_timespan(api, tmpdir):
 
     p = pathlib.Path(str(tmpdir))
     l.write_info(p)
-    print(p.joinpath('abcd1235', 'md.ini').read_text(encoding='utf8'))
     assert '-0001-01-01/0300-01-01' in p.joinpath('abcd1235', 'md.ini').read_text(encoding='utf8')
 
+    l.timespan = (-10000, 2000)
+    assert recwarn.pop(UserWarning)
+
 
 def test_Level(api):
     assert api.languoid_levels.dialect > api.languoid_levels.language
